Package: TOAST
Type: Package
Title: Tools for the analysis of heterogeneous tissues
Version: 1.24.0
Description: This package is devoted to analyzing high-throughput data (e.g. gene expression microarray, DNA methylation microarray, RNA-seq) from complex tissues. Current functionalities include 1. detect cell-type specific or cross-cell type differential signals 2. tree-based differential analysis  3. improve variable selection in reference-free deconvolution 4. partial reference-free deconvolution with prior knowledge.
Author: Ziyi Li and Weiwei Zhang and Luxiao Chen and Hao Wu
Maintainer: Ziyi Li <zli16@mdanderson.org>
License: GPL-2
Encoding: UTF-8
LazyData: false
Depends: R (>= 3.6), EpiDISH, limma, nnls, quadprog
biocViews: DNAMethylation, GeneExpression, DifferentialExpression,
        DifferentialMethylation, Microarray, GeneTarget, Epigenetics,
        MethylationArray
BugReports: https://github.com/ziyili20/TOAST/issues
Imports: stats, methods, SummarizedExperiment, corpcor, doParallel,
        parallel, ggplot2, tidyr, GGally
Suggests: BiocStyle, knitr, rmarkdown, gplots, matrixStats, Matrix
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-10-30 07:00:19 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/TOAST
git_branch: RELEASE_3_22
git_last_commit: a147119
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
